aboutsummaryrefslogtreecommitdiff
path: root/lib/StaticAnalyzer/Frontend/AnalysisConsumer.cpp
diff options
context:
space:
mode:
authorTed Kremenek <kremenek@apple.com>2011-10-24 01:32:45 +0000
committerTed Kremenek <kremenek@apple.com>2011-10-24 01:32:45 +0000
commit1d26f48dc2eea1c07431ca1519d7034a21b9bcff (patch)
tree41d69b4ac2473036f1dcccf82fe01922e94f6de2 /lib/StaticAnalyzer/Frontend/AnalysisConsumer.cpp
parent0b64ba926752110cff1344a46b36e29396cc4d25 (diff)
Rename AnalysisContext to AnalysisDeclContext. Not only is this name more accurate, but it frees up the name AnalysisContext for other uses.
git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@142782 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/StaticAnalyzer/Frontend/AnalysisConsumer.cpp')
-rw-r--r--lib/StaticAnalyzer/Frontend/AnalysisConsumer.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/StaticAnalyzer/Frontend/AnalysisConsumer.cpp b/lib/StaticAnalyzer/Frontend/AnalysisConsumer.cpp
index fdf95b4c7e..ded86b7746 100644
--- a/lib/StaticAnalyzer/Frontend/AnalysisConsumer.cpp
+++ b/lib/StaticAnalyzer/Frontend/AnalysisConsumer.cpp
@@ -278,7 +278,7 @@ void AnalysisConsumer::HandleCode(Decl *D) {
if (!Opts.AnalyzeAll && !SM.isFromMainFile(SL))
return;
// Clear the AnalysisManager of old AnalysisContexts.
Mgr->ClearContexts();
// Dispatch on the actions.
@@ -318,7 +318,7 @@ static void ActionExprEngine(AnalysisConsumer &C, AnalysisManager &mgr,
}
// Execute the worklist algorithm.
- Eng.ExecuteWorkList(mgr.getAnalysisContextManager().getStackFrame(D, 0),
+ Eng.ExecuteWorkList(mgr.getAnalysisDeclContextManager().getStackFrame(D, 0),
mgr.getMaxNodes());
// Release the auditor (if any) so that it doesn't monitor the graph
@@ -278,7 +278,7 @@ void AnalysisConsumer::HandleCode(Decl *D) {
if (!Opts.AnalyzeAll && !SM.isFromMainFile(SL))
return;
- // Clear the AnalysisManager of old AnalysisContexts.
+ // Clear the AnalysisManager of old AnalysisDeclContexts.
Mgr->ClearContexts();
// Dispatch on the actions.